@@ -12,7 +12,7 @@ use Encode;
 
 has toUTF8 => sub { find_encoding('utf8') };
 
-our $VERSION = '1.0.2';
+our $VERSION = '1.0.3';
 
 has 'service';
 
@@ -22,7 +22,7 @@ has 'requestId';
 
 has 'methodName';
 
-has 'params';
+has 'rpcParams';
 
 has log => sub { shift->app->log };
 
@@ -101,7 +101,7 @@ sub dispatch {
     };
     $self->methodName($method);
 
-    $self->params($data->{params} // []);
+    $self->rpcParams($data->{params} // []);
  
     # invocation of method in class according to request 
     my $reply = eval {
@@ -135,18 +135,13 @@ sub dispatch {
              message => "method $method does not exist.", 
              code=> 4
         } if not $self->can($method);
-        if ($log->level eq 'debug'){
-            my $debug = encode_json($self->params);
-            if (not $ENV{MOJO_QX_FULL_RPC_DETAILS}){
-                if (length($debug) > 60){
-                    $debug = substr($debug,0,60) . ' [...]';
-                }
-            }
-            $log->debug("call $method(".$debug.")");
+        $self->logRpcCall($method,$self->rpcParams);
+        
+            
         }
         # reply
         no strict 'refs';
-        return $self->$method(@$self->params);
+        return $self->$method(@$self->rpcParams);
     };
     if ($@){
         $self->renderJsonRpcError($@);
@@ -174,20 +169,39 @@ sub dispatch {
     }
 }
 
+sub logRpcCall {
+    my $self = shift;
+    if ($self->log->level eq 'debug'){
+        my $method = shift;
+        my $request = encode_json(shift);
+        if (not $ENV{MOJO_QX_FULL_RPC_DETAILS}){
+            if (length($request) > 60){
+                $request = substr($request,0,60) . ' [...]';
+            }
+        }
+        $log->debug("call $method(".$request.")");
+    }
+}
+
 sub renderJsonRpcResult {
 	my $self = shift;
 	my $data = shift;
-    my $reply = encode_json({ id => $self->requestId, result => $data });
+    my $reply = { id => $self->requestId, result => $data };
+    $self->logRpcReturn($reply);
+    $self->finalizeJsonRpcReply(encode_json($reply);
+}
+
+sub logRpcReturn {
+    my $self = shift;
     if ($self->log->level eq 'debug'){
-        my $debug = $reply;
+        my $debug = encode_json(shift);
         if (not $ENV{MOJO_QX_FULL_RPC_DETAILS}){
             if (length($debug) > 60){
-               $debug = substr($debug,0,60) . ' [...]';
+                $debug = substr($debug,0,60) . ' [...]';
             }
         }
         $self->log->debug("return ".$debug);
     }
-    $self->finalizeJsonRpcReply($reply);
 }
 
 sub renderJsonRpcError {
